@@ -14,10 +14,20 @@
 #     main()
 from hdfs_lmdc.hdfs import HDFSWrapperClient
 
-a = HDFSWrapperClient.load_from_envs()
-# a.mkdir("/tmp/oi3")
-# a.upload("/home/thaylon/c.jpg", "/tmp")
-# print(a.glob("/tmp"))
+# a = HDFSWrapperClient.load_from_envs()
+# # a.mkdir("/tmp/oi3")
+# # a.upload("/home/thaylon/c.jpg", "/tmp")
+# # for path, dirs, files in a.walk("/tmp"):
+# #     print(path, dirs, files)
+# import  os
+# for path, dirs, files in os.walk("/tmp"):
+#     print(path, dirs, files)
+
 # result = a.read_image("/tmp/c.jpg")
 # print(a.read_txt("/tmp/producao-terra-2014-1sem.csv"))
-# print(a.download("/tmp/c.jpg", "/tmp")[1].erro)
\ No newline at end of file
+# print(a.download("/tmp/c.jpg", "/tmp")[1].erro)
+
+from hdfs3 import HDFileSystem
+hdfs = HDFileSystem(host='sandbox-hdp.hortonworks.com', port=8020)
+a = hdfs.ls('/tmp')
+print(a)
\ No newline at end of file
